@@ -1,15 +1,20 @@
-
+from pywizard.facts import is_ubuntu, is_centos, distro
 from pywizard.resources.file import file_, directory
 from pywizard.resources.package import package
 from pywizard.resources.service import service
 from pywizard.resources.shell import shell
+from pywizard.resources.user import user
 from pywizard.templating import tpl
 from pywizard.utils.process import run
 from pywizard.utils.resources import aggregate_config
 
 
-def nginx_dev(version):
-    package('make libc6 libpcre3 libpcre3-dev libpcrecpp0 libssl0.9.8 libssl-dev zlib1g zlib1g-dev lsb-base'.split(' '))
+def nginx_dev(version, user='nginx'):
+
+    if is_ubuntu():
+        package('make libc6 libpcre3 libpcre3-dev libpcrecpp0 libssl0.9.8 libssl-dev zlib1g zlib1g-dev lsb-base'.split(' '))
+    if is_centos():
+        package('pcre pcre-devel zlib zlib-devel openssl openssl-devel'.split(' '))
 
     def nginx_installed():
         return version in str(run('nginx -v  2>&1', ignore_errors=True))
@@ -21,7 +26,7 @@ def nginx_dev(version):
 
     def set_rights():
         run('chmod +x /etc/init.d/nginx')
-    file_('/etc/init.d/nginx', tpl('nginx-init'), on_create=set_rights)
+    file_('/etc/init.d/nginx', tpl('nginx-init-%s' % distro()), on_create=set_rights)
 
 
 def nginx(
@@ -35,7 +40,9 @@ def nginx(
 
     config = aggregate_config(nginx, '%s' % name, kwargs)
 
-    nginx_dev('1.3.15')
+    user('nginx')
+
+    nginx_dev('1.3.15', user='nginx')
     #package('nginx-full')
 
     nginx_service = service('nginx', start=False)
